diff --git a/src/video_core/textures/decoders.cpp b/src/video_core/textures/decoders.cpp
index 1bccc09d9..f1f523ad1 100644
--- a/src/video_core/textures/decoders.cpp
+++ b/src/video_core/textures/decoders.cpp
@@ -66,9 +66,9 @@ void Swizzle(std::span<u8> output, std::span<const u8> input, u32 bytes_per_pixe
                 if (const auto offset = (TO_LINEAR ? unswizzled_offset : swizzled_offset);
                     offset >= input.size()) {
                     // TODO(Rodrigo): This is an out of bounds access that should never happen. To
                     // avoid crashing the emulator, continue.
                     ASSERT_MSG(false, "offset {} exceeds input size {}!", offset, input.size());
-                    continue;
+                    break;
                 }
 
                 u8* const dst = &output[TO_LINEAR ? swizzled_offset : unswizzled_offset];
@@ -66,9 +66,9 @@ void Swizzle(std::span<u8> output, std::span<const u8> input, u32 bytes_per_pixe
                     offset >= input.size()) {
                     // TODO(Rodrigo): This is an out of bounds access that should never happen. To
-                    // avoid crashing the emulator, continue.
+                    // avoid crashing the emulator, break.
                     ASSERT_MSG(false, "offset {} exceeds input size {}!", offset, input.size());